package com.acme.shoppingcart.model;

import java.util.Vector;
import java.util.Iterator;

import com.eknowlogie.aliorsum.UIFactory;
import com.eknowlogie.business.aliorsum.BusinessPrefs;
import com.acme.shoppingcart.aliorsum.ShoppingCartPrefs;

/** <p>This class represents the product catalog for the shopping cart 
    application.</p>
*/

public class Catalog {

   /*-------------------------- Begin Fields --------------------------*/

   static Vector recommendedProducts = new Vector (); /* Vector of RecommendedProduct */
   static Vector categories = new Vector (); /* Vector of Category */
   static Vector products = new Vector ();

   static Category electronics = new Category (1, "Electronics");
   static Category appliances = new Category (2, "Appliances");
   static Category toys = new Category (3, "Toys");
   static Category books = new Category (4, "Books");
   
   /** <p>Currently we are using one common UI factory for all visitors.  
       Later we can create one more UI factory for the inventory manager, 
       etc.  This factory needs to be made available in the session object 
       for each visitor.</p>
   */
   
   static UIFactory uif = new UIFactory (false);
   
   static {
      BusinessPrefs. register (uif);
      ShoppingCartPrefs. register (uif);
   }

   static {
      categories. add (electronics);
      categories. add (appliances);
      categories. add (toys);
      categories. add (books);

      Product cdPlayer = new Product (1, "Sony Portable CD Player", "Anti-shock, water-proof, with programable functions", electronics, "CD music", 59.99f, 10);
      Product nokiaCell = new Product (2, "Nokia Cell Phone", "Intercom functionality, built-in digital camera", electronics, "phone cellular", 149.99f, 10);
      Product toaster = new Product (3, "GE Toaster", "With variable timer, for two slices", appliances, "toast kitchen", 19.99f, 15);
      
      products. add (cdPlayer);
      products. add (nokiaCell);
      products. add (toaster);

      recommendedProducts. add (new RecommendedProduct (cdPlayer, 3));
      recommendedProducts. add (new RecommendedProduct (nokiaCell, 4));
      recommendedProducts. add (new RecommendedProduct (toaster, 4));
   } 

   /*--------------------------- End Fields ---------------------------*/

   /*---------------------- Begin Static Methods ----------------------*/

   public static Vector getRecommendations () {
      return recommendedProducts;
   }

   public static Vector getCategories () {
      return categories;
   }

   public static Product getProduct (int productKey) {
      Iterator it = products. iterator ();
      while (it. hasNext ()) {
         Product product = (Product) it. next ();
         if (product. key. val == productKey)
            return product;
      }
      return null;
   }
   
   public static Category getCategory (int categoryKey) {
      Iterator it = categories. iterator ();
      while (it. hasNext ()) {
         Category category = (Category) it. next ();
         if (category. key. val == categoryKey)
            return category;
      }
      return null;
   }

   public static Vector selectProductsByKeyword (String keyword) {
      return null;
   }

   public static Vector selectProductsByCategory (int categoryId) {
      Category category = getCategory (categoryId);
      return selectProductsByCategory (category);
   }
   
   public static Vector selectProductsByCategory (Category category) {
      Vector selectedProducts = new Vector ();
      Iterator it = products. iterator ();
      while (it. hasNext ()) {
         Product product = (Product) it. next ();
         if (product. category == category) 
            selectedProducts. add (product);
      }
      return selectedProducts;
   }

   /*----------------------- End Static Methods -----------------------*/

   /* End of Catalog */
}