/* 
   (C) Copyright 2004 eKnowlogie Inc., All rights reserved.
   eKnowlogie Proprietary / Confidential.  Use is subject to license terms.
*/

package com.eknowlogie.aliorsum;

import java.util.Hashtable;

import com.eknowlogie.aliorsum.prefs.Pref;
import com.eknowlogie.util.DeferredHashTable;

/** <p>A <b>class preference registry</b> is used to register <b>class-specific 
    preferences</b>.  These are preferences which are registered for specific 
    classes in the domain model, and they supersede default preferences.  For 
    example, a title for all CreditCard objects could be specified as "Credit 
    Card (Visa or MasterCard only)" to indicate a company-wide billing policy. 
    If the understanding is that the vast majority of currency fields are derived 
    by application calculations and seldom determined by user input, The access 
    mode for the Currency class could be specified as read-only. This table's 
    entries are defined as (Class anyRecipientClass, Hashtable classPrefs), 
    where classPrefs is defined as (Pref preferenceId, Object preferenceValue). 
    Under Java 5.0, this map types should be made explicit.</p>

    @author Romel Rivera, eKnowlogie. Inc.
*/

public class ClassPrefsRegistry extends DeferredHashTable {
	
  /*------------------------- Begin Methods --------------------------*/
	
  /** <p>This method registers a preference with the name "prefName" and the 
      value "prefValue" for class "recipientClass".</p>
  */

   public void register (Class recipientClass, Pref preferenceId, Object prefValue) {
      Hashtable prefs = (Hashtable) get (recipientClass);
      if (prefs == null) {
         prefs = new Hashtable ();
         put (recipientClass, prefs);
      }
      prefs. put (preferenceId, prefValue);
   }
   
  /** <p>This method registers a preference with the name "prefName" and the 
      boolean value "prefValue" for class "recipientClass".</p>
  */
   
   public void register (Class recipientClass, Pref preferenceId, boolean prefValue) {
      register (recipientClass, preferenceId, new Boolean (prefValue));
   }
   
  /** <p>This method registers a preference with the name "prefName" and the 
      int value "prefValue" for class "recipientClass".</p>
  */
   
   public void register (Class recipientClass, Pref preferenceId, int prefValue) {
      register (recipientClass, preferenceId, new Integer (prefValue));
   }
   
   /*-------------------------- End Methods ---------------------------*/

   /* End of ClassPrefsRegistry */
}