/* 
   (C) Copyright 2004 eKnowlogie Inc., All rights reserved.
   eKnowlogie Proprietary / Confidential.  Use is subject to license terms.
*/

package com.eknowlogie.aliorsum;

import java.util.Hashtable;
import java.lang.reflect.Field;

import com.eknowlogie.aliorsum.prefs.Pref;
import com.eknowlogie.util.DeferredHashTable;

/** <p>A <b>field preference registry</b> is used to register <b>field-specific 
    preferences</b>.  These are preferences which are registered for specific 
    class fields in the domain model, and they supersede class preferences.  For 
    example, all Date objects can be managed with an elementary DateUI class, except 
    for the Date field "expirationDate" in CreditCard class which can be managed 
    with an elementary FutureDateUI to validate that the date entered will cover 
    a certain period of card activity.  This table's entries are defined as 
    (Field anyRecipientField, Hashtable fieldPrefs), where fieldPrefs is defined 
    as (Pref preferenceId, Object preferenceValue).  Under Java 5.0, this map 
    types should be made explicit.</p>

    @author Romel Rivera, eKnowlogie. Inc.
*/

public class FieldPrefsRegistry extends DeferredHashTable {
	
   /*------------------------- Begin Methods --------------------------*/
	
   /** <p>This method registers a preference with the name "prefName" and the 
       value "prefValue" for field with the given field name in recipientClass.</p>
   */
   
   public void register (String fieldName, Class recipientClass, Pref preferenceId, Object prefValue) {
      
      try { 
         Field field = recipientClass. getField (fieldName); 
         register (field, preferenceId, prefValue);
      }
      catch (Exception e) { throw new Error (e. getMessage ()); }
   }
   
   /** <p>This method registers a preference with the name "prefName" and the 
       value "prefValue" for the given field.</p>
   */

   public void register (Field field, Pref preferenceId, Object prefValue) {
      Hashtable prefs = (Hashtable) get (field);
      if (prefs == null) {
         prefs = new Hashtable ();
         put (field, prefs);
      }
      prefs. put (preferenceId, prefValue);
   }
   
   /** <p>This method registers a preference with the name "prefName" and  
       the boolean value "prefValue" for the field with the given field name 
       in recipientClass.</p>
   */
   
   public void register (String fieldName, Class recipientClass, Pref preferenceId, boolean prefValue) {
      register (fieldName, recipientClass, preferenceId, new Boolean (prefValue));
   }
   
   /** <p>This method registers a preference with the name "prefName" and  
       the int value "prefValue" for the field with the given field name in 
       recipientClass.</p>
   */
   
   public void register (String fieldName, Class recipientClass, Pref preferenceId, int prefValue) {
      register (fieldName, recipientClass, preferenceId, new Integer (prefValue));
   }
   
   /** <p>This method registers a preference with the name "prefName" and  
       the value "prefValue" for all fields in recipientClass.</p>
   */
   
   public void registerAllFields (Class recipientClass, Pref preferenceId, Object prefValue) {
   	  Field [] field = recipientClass. getFields ();
   	  
   	  for (int ix = 0; ix < field. length; ix ++) {
   	     register (field [ix], preferenceId, prefValue);
   	  }
   }
   
   /*-------------------------- End Methods ---------------------------*/

   /* End of FieldPrefsRegistry */
}