/* 
   (C) Copyright 2004 eKnowlogie Inc., All rights reserved.
   eKnowlogie Proprietary / Confidential.  Use is subject to license terms.
*/

package com.eknowlogie.aliorsum;

import java.util.*;
import java.lang.reflect.Field;
import javax.servlet.jsp.PageContext;

import com.eknowlogie.aliorsum.prefs.*;

/** <p>A ListUI class manages the presentation of list recipients by managing the 
    presentation of its list elements. A list UI relies on JSP renderers 
    to render its recipient in terms of its elements.  This ListUI is suitable for 
    rendering a list as a table where each element is a row, each column is an 
    element field and a column header is an element field title.</p>
    
    <p>Current Restrictions. This class will be updated to support automatic multi-page 
    navigation of large lists.  The list elements are currently pressumed to be of the 
    same type.  It currently offers not mechanism for adding or deleting list elements.</p>
    
    @author Romel Rivera, eKnowlogie. Inc.
*/

public class ListUI extends CompositeUI {
	
   /** <p>This is the class of the elements in the list.  It is assumed that all 
       elements are instances of this class.</p>
   */
	
   protected Class elementClass;
   
   /** <p>These are all the element fields.</p> */
   
   protected Vector columnFields; 
   
   /** <p>This is a counter used to uniquely identify and name each element.</p> */
   
   protected int renderingIndex = 0;
   
   /** <p>This table is used to assign unique names during the qualified name formation 
       for each element.</p>
   */
   
   protected Hashtable elementNumber = new Hashtable ();
   
   protected CompositeUI beginUIRendering (Object initialRecipient, Class initialRecipientClass, PageContext pageContext, String simpleName) {
      ListUI lui = (ListUI) super. beginUIRendering (initialRecipient, initialRecipientClass, pageContext, simpleName);
      if (! (lui. recipient instanceof List)) 
         throw new Error ("beginUIRendering expected the recipient to be a list.");
      else if (((List) lui. recipient). size () != 0)
         lui. elementClass = ((List) lui. recipient). get (0). getClass ();
      return lui;
   }
   
   protected boolean willVisitField (Field field) {
      return ! Prefs. ACCESS. isHidden (field, this); 
   }
   
   /** <p>A convenience method for presetting a new composite UI which happens to be an 
       object directly contained in the recipient of this UI currently being rendered. 
       Typically, the object will be a list element and this UI's recipient will be a 
       list.</p>
   */
   
   public CompositeUI presetUIRendering (Object element) {
      Integer i = (Integer) elementNumber. get (element);
      if (i == null) {
         i = new Integer (renderingIndex ++);
		 elementNumber. put (element, i);
      }
      CompositeUI ui = presetUIRendering (element, uiActivity, i. toString ());
      return ui;
   }
   
   /** <p>This class is an iterator over the composite UI for this list recipient's elements, 
       and is used to preset for rendering each composite UI prior to delivery by next ().</p>
   */
   
   public class ListUIIterator extends CompositeUI. CompositeUIIterator {
   	  
      public ListUIIterator (Iterator it, CompositeUI parentUI) { 
         super (it, parentUI);
      }

      /** <p>Presets for rendering the UI of this list recipient's element before returning 
          it as next ().</p>
      */
      
      public Object next () {
         currElementaryUI = null;
         return ((ListUI) parentUI). presetUIRendering (it. next ());
      }
   }
   
   /** {@inheritDoc}
   
       <p>This method returns an iterator over the UIs for the elements in the 
       recipient list.</p>
   */
   
   public Iterator childrenUIs () {
      return new ListUIIterator (((List) recipient). iterator (), this);
   }
   
   /** <p>This method returns the table header object to be used to render the header 
       for this composite UI.</p>
   */
   
   public TableHeader header () {
      if (header == null)
         header =  new HierarchicalTableHeader (this, elementClass);
      return header;
   }
   
   /** <p>Returns true is the recipient list is empty.</p> */
   
   public boolean isEmpty () {
      return ((Vector) getRecipient ()). isEmpty ();
   }
   
}
