/* 
   (C) Copyright 2004 eKnowlogie Inc., All rights reserved.
   eKnowlogie Proprietary / Confidential.  Use is subject to license terms.
*/

package com.eknowlogie.aliorsum; 

import java.util.Iterator;
import java.util.Vector;
import java.lang.reflect.Field;

/** <p>This class is used to render a table header for a table displaying an object's 
    value by displaying all the elementary fields in its structure.  A row in this table 
    structure consists of the flat representation of the given object, where each column 
    corresponds to a visible leaf elementary field in the object structure's tree.  If 
    the object is a List then the table contains one row for each list element displayed, 
    otherwise the table contains one single row.</p>
    
    <p>This table header is rendered as one single header row where each column corresponds 
    to each elementary field in the object structure.</p>
    
    @author Romel Rivera, eKnowlogie. Inc.
*/

public class TableHeader {
      
   /** <p>This is a list of all the elementary fields in the object's tree structure. 
       The element type in this vector is Field or String.</p> 
   */
      
   private Vector leaf; 
      
   /** <p>This is the class of the object being represented by the table.</p> */
      
   protected Class headerClass;
      
   /** <p>This is the composite UI to be used to render this table.</p> */
      
   protected CompositeUI ui;
      
   /** <p>This is the Html string representation of this table header.</p> */
      
   protected String header;
      
   /** <p>If true, this flag indicates that once the resulting Html header has 
       been produced, it can be cached and does not need to be recomputed again.</p>
   */
      
   protected boolean cached = true;
      
   /** <p>This constructor indicates that this table header will be used for rendering 
       of the table through this composite UI, and for an object of type headerClass.</p>
   */
      
   public TableHeader (CompositeUI ui, Class headerClass) {
      this. headerClass = headerClass;
      this. ui = ui;
   }
      
   /** <p>This method returns the Html string to be used to render the header.</p> */
      
   public String render () {
      	
      if (cached == true && header != null)
         return header;
         
      buildHeader ();
      int numCols = leaf. size ();
      header = "<thead class = \"listHeader\"> <tr";
      Iterator it = leaf. iterator ();
      while (it. hasNext ()) {
         Object column = it. next ();
         if (column instanceof Field)
            header += "<th>" + ui. renderTitle ((Field) column) + "</th>";
         else if (column instanceof String)
            header += "<th>" + column + "</th>";
      }
      header += "</tr></thead>";
      return header;
   }
   
   public void buildHeader () {
      if (leaf == null) {
         leaf = new Vector ();
         if (headerClass != null)
            leafer (headerClass);
      }
   }
   
   public void addColumn (String colTitle) {
      buildHeader ();
      header = null;
      leaf. add (colTitle);
   }
   
   public int numCols () {
      return leaf. size ();
   }
      
   /** <p>This method creates the list of all leaf elementary fields found in the 
       object structure tree.  The list is stored in vector <code>leaf</code>.</p>
   */
   
   private void leafer (Class thisClass) {
      	
      Iterator it = ui. fields (thisClass);
      while (it. hasNext ()) {
         Field field = (Field) it. next ();
         if (ui. uiActivity. localFactory. hasElementaryUI (field. getType ()))
            leaf. add (field);
   	     else leafer (field. getType ());
      }
   }
   
   /* End of TableHeader */
}

   