/* 
   (C) Copyright 2004 eKnowlogie Inc., All rights reserved.
   eKnowlogie Proprietary / Confidential.  Use is subject to license terms.
*/

package com.eknowlogie.aliorsum.prefs;

import java.lang.reflect.Field;

import com.eknowlogie.aliorsum.UI;
import com.eknowlogie.aliorsum.UIFactory;

   /** <p>This is the Access enumeration preference and it is of the same enumeration type 
       as the {@link Display} preference.  It can only take on the values HIDDEN, READ_ONLY, 
       WRITE_ONLY, READ_AND_WRITE.  It helps determine the allowed privilege granted for a 
       given field.  See {@link Display} for details on how to use this preference.</p>
       
       @author Romel Rivera, eKnowlogie. Inc.
   */


public class Access extends Pref {
	
   /*-------------------------- Begin Fields --------------------------*/
	
   /** <p>HIDDEN is a value of the ACCESS and DISPLAY preferences.  It means that the preference 
       recipient cannot be displayed.</p>
   */
   
   public static final Integer HIDDEN = new Integer (1);
   
   /** <p>READ_ONLY is a value of the ACCESS and DISPLAY preferences.  It means that the preference 
       recipient cannot be modified.</p>
   */
   
   public static final Integer READ_ONLY = new Integer (2);
   
   /** <p>WRITE_ONLY is a value of the ACCESS and DISPLAY preferences.  It means that the  
       preference recipient cannot be read but it can be input or modified.  This means it  
       needs to be displayed in a style similar to that used for passwords, where characters  
       in the input field are shown as black circles, etc.</p>
   */
   
   public static final Integer WRITE_ONLY = new Integer (3);

   /** <p>READ_AND_WRITE is a value of the ACCESS and DISPLAY preferences.  It means 
       that the preference recipient can be both displayed and modified by the user.</p>
   */
   
   public static final Integer READ_AND_WRITE = new Integer (4);
   
   /*--------------------------- End Fields ---------------------------*/
  
   /*----------------------- Begin Constructors -----------------------*/
   
   
   /** @see Pref#Pref(String) */
   
   public Access (String name) { super (name); }
   
   /** @see Pref#Pref(String, boolean) */
   
   public Access (String name, boolean inheritable) { 
   	super (name, inheritable); 
   }
   
   /*------------------------ End Constructors ------------------------*/

   /*-------------------------- Begin Methods -------------------------*/
   
   /** <p>This method returns true if the value of this cascading preference for 
       preference recipient "field" is HIDDEN, false otherwise.</p>
       
       @see UIFactory#getPref(Field, Pref, UI)
   */
   
   public boolean isHidden (Field field, UI enclosingUI) { 
      int accessValue = enclosingUI. getFactory (). getIntPref (field, this, enclosingUI);
      return accessValue == HIDDEN. intValue ();
   }
   
   /*--------------------------- End Methods --------------------------*/
   
   /* End of Display */
   
}
