/* 
   (C) Copyright 2004 eKnowlogie Inc., All rights reserved.
   eKnowlogie Proprietary / Confidential.  Use is subject to license terms.
*/

package com.eknowlogie.aliorsum.prefs;

import java.util.Hashtable;
import java.lang.reflect.Field;
import com.eknowlogie.aliorsum.UI;
import com.eknowlogie.aliorsum.Classes;

   /** <p>This is the TITLE String preference.  This preference does not have an invariant 
       default, but instead each preference recipient can have its own individualized default.  
       Therefore if the cascading renders this preference value undefined, the individualized 
       default for the recipient is used.</p>
    
       @author Romel Rivera, eKnowlogie. Inc.
   */

public class Title extends Pref {
	
   /*-------------------------- Begin Fields --------------------------*/
	
   /** <p>A map from a field name to its default title. If a default title is needed for  
       a field name, and this table does not have it, then one is created on the fly and 
       stored on this table for subsequent use.  These titles are used for automatic 
       display during rendering.  These table entries are as follows: (String, String).</p>
   */
   
   protected static Hashtable defaultTitles = new Hashtable ();
	      
   /*--------------------------- End Fields ---------------------------*/
   
   /*----------------------- Begin Constructors -----------------------*/
   
   
   /** <p>This is the only parameterless constructor needed.</p> */
   
   public Title () { super ("Title", false); }
   
   /*------------------------ End Constructors ------------------------*/

   /*-------------------------- Begin Methods -------------------------*/
   
   /** <p>This internal method is called if a search for a TITLE preference fails and 
       a default title is needed for a given field name. The field title can be used 
       for labeling the field's value or the field's input during rendering.</p>
   */

   protected static String getDefaultTitle (String fieldName) {

      String title = (String) defaultTitles. get (fieldName);
      if (title != null) {
         return title;
      }
  
      StringBuffer titleBuffer = new StringBuffer ();
      if (fieldName. length () > 0) {
         titleBuffer. append (Character. toUpperCase (fieldName. charAt (0)));
         boolean previousWasLetter = true;
         for (int ix = 1; ix < fieldName. length (); ix ++ ) {
         	char ch = fieldName. charAt (ix);
         	if (Character. isDigit (ch) && previousWasLetter || Character. isLetter (ch)  && ! previousWasLetter) {
         	   titleBuffer. append (" ");
         	   previousWasLetter = ! previousWasLetter;
         	}
            if (Character. isUpperCase (ch)) {
        	   titleBuffer. append (" ");
            }
            titleBuffer. append (ch);
         }
      }
      title = titleBuffer. toString ();
      defaultTitles. put (fieldName, title);
      return title;
   }
   
   /** <p>This method returns the value of cascading preference TITLE for 
       preference target recipient at "ui".  If none was found, an individualized 
       title default for this ui's recipient is created and returned.</p>
   */
   
   public String getTitle (UI ui) {
      String title = (String) super. get (ui);
      if (title == null) 
         if (ui. recipientField != null)
            return getDefaultTitle (ui. recipientField. getName ());
         else return getDefaultTitle (Classes. getUnqualifiedName (ui. recipientClass));
      else return title;
   }

   /** <p>This method returns a title preference as described in {@link #getTitle(UI)}, 
       except that the title is for the specified orphan field, that is, a field that is not 
       necessarily directly enclosed in the recipient for the given UI.  An enclosing UI is 
       not needed in this situation since none of the preferences needed to render a title 
       are inheritable.</p>
   */
   
   public String getTitle (Field field, UI unrelatedUI) {
      String title = (String) super. get (field, unrelatedUI);
      if (title == null) 
         return getDefaultTitle (field. getName ());
      else return title;
   }


   /*--------------------------- End Methods --------------------------*/
   
   /* End of Title */
   
}
