/* 
   (C) Copyright 2004 eKnowlogie Inc., All rights reserved.
   eKnowlogie Proprietary / Confidential.  Use is subject to license terms.
*/

package com.eknowlogie.aliorsum.primitive;

import com.eknowlogie.aliorsum.ElementaryUI;

/** <p>This elementary UI supports elements of type boolean  and Boolean.  That  
    is convenient because for a class field of type boolean, the reflective field 
    type (i.e. "field. getType ()") will be boolean, but the reflective extraction 
    of its value (i.e. "field. get (parentObject)") returns an object of type 
    Boolean.  Methods in this class render this field as a checkbox for user-input.<p>

    @author Romel Rivera, eKnowlogie. Inc.
*/

public class BooleanUI extends ElementaryUI {

   /*------------------------- Begin Methods --------------------------*/
	
   public boolean validate (String inputValue) {
      Boolean booleanVal = new Boolean (inputValue != null);
      setValue (booleanVal);
      return true;
   }
   
   /** {@inheritDoc}
     
       <p>For a boolean or Boolean recipient with a checkbox UI, its input value 
       is never missing.</p>
   */
   
   public boolean isMissingRequired (String inputValue) {
      return false;
   }
   
   public Object parse (String inputValue) {
      return new Boolean (inputValue != null);
   }
   
   /** {@inheritDoc}
       
       <p>When the boolean field is writable, this method accepts boolean input 
       as a checkbox.</p>
   */
   
   public String renderVal () {
   	
       if (isReadOnly ()) 
          return renderTitleAndValidation () + " " + format ();
       else {
          inputRequested = true;
       	  Boolean value = (Boolean) getValue ();
          String html = "<input type = \"checkbox\" name = \"" + qualifiedName + "\""; 
          if (value != null && value. booleanValue ()) {
             html += " checked = \"checked\"";
          }
          html += " value = \"" + getTitle () + "\" /> " + getTitle ();
          return html;
       }
   }
   
   /** {@inheritDoc}
       
       <p>When the boolean field is writable, this method accepts boolean input 
       as a checkbox.  It spans the presentation of this boolean field over two 
       columns without any separation.</p>
   */
    
   public String renderCols () {
      return "<tr><td colspan = \"2\">" + renderVal () + "</td></tr>";
   }
    
   /*-------------------------- End Methods ---------------------------*/

   /* End of BooleanUI */
}

