/* 
   (C) Copyright 2004 eKnowlogie Inc., All rights reserved.
   eKnowlogie Proprietary / Confidential.  Use is subject to license terms.
*/

package com.eknowlogie.aliorsum.primitive;

import java.util.HashSet;
import javax.servlet.jsp.PageContext;
import javax.servlet.http.HttpServletRequest;
import com.eknowlogie.aliorsum.*;

/** <p>This elementary UI renders an int or Integer recipient as a counter, by allowing 
    its modification through two buttons to increment or decrement its value by one.  The 
    modifiable mode of this recipient is rendered by renderVal () using an internal elementary 
    JSP renderer.</p>
   
    @author Romel Rivera, eKnowlogie. Inc.
*/

public class CounterUI extends ElementaryUI {

   /*------------------------- Begin Methods --------------------------*/
   
   /** <p>This is the extension of the validate method for ElementaryUI.  The new value for 
       for this int or Integer recipient is calculated by incrementing or decrementing its 
       original value, depending on the submission of its increment or decrement button.</p> 
       
       @see ElementaryUI#validate(PageContext)
   */

   public boolean validate (PageContext pageContext) {
   	      
      HttpServletRequest request = (HttpServletRequest) pageContext. getRequest ();
   	  String incr = request. getParameter (qualifiedName + "_incr");
   	  String decr = request. getParameter (qualifiedName + "_decr");
   	  
   	  valid = true;
   	  if (isReadOnly () || ! wasInputSubmitted ()) 
   	     return true;
   	  
   	  invalidInputValue = null;
   	  validationMessages = new HashSet ();
   	  
   	  submissionCount ++;
   	  int value = ((Integer) getValue ()). intValue ();
   	  if (incr != null) 
         setValue (new Integer (++ value));
	  else if (decr != null)
	     setValue (new Integer (-- value));
	  
   	  return valid;
   }
   
   /** {@inheritDoc}
       
       <p>This method uses the JSP renderer "CounterUIRenderer.jsp" to produce the value for this 
       recipient.  The modifiable mode for this recipient consists of two buttons to increment 
       or decrement its value by one.</p>
   */
   
   public String renderVal () {
      if (isReadOnly ()) 
         return format ();
      else {
      	 inputRequested = true;
         return include ("CounterUIRenderer.jsp");
      }
   }

   /*-------------------------- End Methods ---------------------------*/

   /* End of CounterUI */
}

