/* 
   (C) Copyright 2004 eKnowlogie Inc., All rights reserved.
   eKnowlogie Proprietary / Confidential.  Use is subject to license terms.
*/

package com.eknowlogie.aliorsum.primitive;

import java.util.Iterator;
import com.eknowlogie.util.EnumerationType;

/** <p>This elementary UI supports elements of type EnumerationType, to be replaced 
    with the new enumeration type in Java 5.0.  For user-input, methods in this class 
    render this field as a sequence of radio buttons. Other implementations can render 
    it as a drop-down menu.  The methods in this class update a recipient object without 
    replacing the object.<p>
  
    @author Romel Rivera, eKnowlogie. Inc.
*/

public class EnumerationRadioUI extends IntegerUI {

   /*------------------------- Begin Methods --------------------------*/
   
   public boolean validate (String inputValue) {
      Integer i = (Integer) parse (inputValue);
      if (i != null) {
         EnumerationType e = (EnumerationType) getValue ();
         e. value = i. intValue ();
      }
      return i != null;
   }
   
   /** {@inheritDoc}
    
       <p>For read-only formatting, this field is displayed as the external 
       string of the enumerated value currently selected.</p>
   */

   public String format () {
      if (invalidInputValue != null) 
         return invalidInputValue;
      else {
      	 EnumerationType e = (EnumerationType) getValue ();
      	 return (String) e. choices. get (e. value);
      }
   }
   
   /** {@inheritDoc}
       
       <p>When the boolean field is writable, this method accepts input 
       from a sequence of radio buttons.  For read-only formatting, 
       this field is displayed as the external string of the enumerated 
       value currently selected.</p>
   */
   
   public String renderVal () {
   	
      EnumerationType e = (EnumerationType) getValue ();
      if (isReadOnly ()) {
         return format ();
      }
      else {
      	 inputRequested = true;
      	 String html = "";
      	 Iterator it = e. choices. iterator ();
      	 int ix = 0;
      	 while (it. hasNext ()) {
      	 	ix ++;
      	 	html += "<br/> &nbsp; &nbsp; &nbsp;" +
			        "<input type = \"radio\" name = \"" + qualifiedName + "\"" + " value = \"" + ix + "\"";
      	 	if (e. value == ix) {
      	       html += " checked = \"checked\"";
      	 	}
      	 	html += " /> " + (String) it. next ();
      	 }
         return html;
      }
   }
   
   /** {@inheritDoc}
       
       <p>When the boolean field is writable, this method accepts input 
       from a sequence of radio buttons.  For read-only formatting, 
       this field is displayed as the external string of the enumerated 
       value currently selected.</p>
   */
   
   public String renderCols () {
      return "<tr><td colspan = \"2\">" 
	         + renderTitleAndValidation () + " " + renderVal () 
			 + "</td></tr>";
   }
   
   public String renderTitleAndValidation () {
      return "<b>" + super. renderTitleAndValidation () + "</b>";
   }
    
   /*-------------------------- End Methods ---------------------------*/

   /* End of EnumerationRadioUI */
}

