/* 
   (C) Copyright 2004 eKnowlogie Inc., All rights reserved.
   eKnowlogie Proprietary / Confidential.  Use is subject to license terms.
*/

package com.eknowlogie.business.aliorsum;

import java.math.BigDecimal;
import java.text.NumberFormat;
import java.text.ParsePosition;
import java.util.Locale;
import com.eknowlogie.aliorsum.ElementaryUI;

/** <p>Class BigDecimalUI implements presentation functions for elementary type 
    BigDecimal.</p>

    @author Romel Rivera, eKnowlogie. Inc.
*/

public class BigDecimalUI extends ElementaryUI {
	
   /** <p>This is the number format to be used for a recipient of type BigDecimal.</p> */
	
   protected NumberFormat numberFormat;
   
   /** <p>Holds the wording for the invalid input validation message to be used for  
       recipients of type BigDecimal or subclasses.</p>
   */
   
   protected String validationMsg;
   
   /** <p>Constructor for this ElementaryUI.  It sets the number format to the appropiate 
       Locale and the exact wording on the validation message to be used.</p>
   */
   
   public BigDecimalUI () {
      numberFormat = NumberFormat. getInstance (Locale. US); // TODO Internationalize
      validationMsg = INVALID_NUMERIC_FORMAT;
   }

   /*------------------------- Begin Methods --------------------------*/
   
   public boolean validate (String inputValue) {
      Double asDouble = (Double) parse (inputValue);
      if (asDouble == null) 
         return false;
      
      BigDecimal value = new BigDecimal (asDouble. doubleValue ());
      setValue (value);
      return true;
   }
   
   /** {@inheritDoc}
    
       <p>This method parses the pressumed-BigDecimal input text as a Double and 
       returns a Double.</p> 
   */
	
   public Object parse (String inputValue) {
   	
      if (inputValue == null || inputValue. length () == 0) {
         addValidation (validationMsg);
         return null;
      }

      ParsePosition pos = new ParsePosition (0);
      Number number = numberFormat. parse (inputValue, pos);
      if (pos. getIndex () < inputValue. length ()) {
         addValidation (validationMsg);
         return null;
      }
      else if (number instanceof Double)
         return ((Double) number);
      else return new Double (((Long) number). doubleValue ());
   }
   
   public String format () {
      if (invalidInputValue != null) 
         return invalidInputValue;
      else {
      	 BigDecimal value = (BigDecimal) getValue ();
      	 if (value == null)
            return "";
         else return numberFormat. format (value. doubleValue ());
      }
   }
    
   /*-------------------------- End Methods ---------------------------*/

   /* End of BigDecimalUI */
}

