/* 
   (C) Copyright 2004 eKnowlogie Inc., All rights reserved.
   eKnowlogie Proprietary / Confidential.  Use is subject to license terms.
*/

package com.eknowlogie.business.aliorsum;

import java.text.NumberFormat;
import java.util.Locale;
import java.text.ParsePosition;

import com.eknowlogie.aliorsum.primitive.DoubleUI;
import com.eknowlogie.business.model.CurrencyDouble;

/** <p>Class CurrencyDecimalUI implements presentation functions for elementary type 
    CurrencyDecimal.</p>

    @author Romel Rivera, eKnowlogie. Inc.
*/

public class CurrencyDoubleUI extends DoubleUI {
	
   /** <p>This is the number format to be used for a recipient of type Currency.</p> */
	
   protected static NumberFormat CURRENCY_FORMAT = NumberFormat. getCurrencyInstance (Locale. US); 
   
   /** <p>This is the number format to be used for a recipient of type Currency.</p> */
	
   protected NumberFormat numberFormat; 
	
   /** <p>Wording for validation message for currency input. </p> */
	
   public static final String INVALID_CURRENCY_FORMAT = "Currency amount expected.";
   
   /** <p>Creates a new instance of this class and sets up the currency locale.</p> */
   
   public CurrencyDoubleUI () {
      numberFormat = NumberFormat. getCurrencyInstance (Locale. US); 
   }

   /*------------------------- Begin Methods --------------------------*/
	
   public Object parse (String inputValue) {
   	
      if (inputValue == null || inputValue. length () == 0) {
         addValidation (INVALID_CURRENCY_FORMAT);
         return null;
      }

      ParsePosition pos = new ParsePosition (0);
      Number number = numberFormat. parse (inputValue, pos);
      if (pos. getIndex () < inputValue. length ()) {
         addValidation (INVALID_CURRENCY_FORMAT);
         return null;
      }
      else if (number instanceof Double)
         return new CurrencyDouble (((Double) number). doubleValue ());
      else return new CurrencyDouble (((Long) number). doubleValue ());
   }
   
   public String format () {
      if (invalidInputValue != null) 
         return invalidInputValue;
      else {
      	 double value = ((CurrencyDouble) getValue ()). val;
      	 return numberFormat. format (value);
      }
   }
   
   /** <p>Convenience method to format an object.</p> */
   
   public static String format (Object obj) {
      // TODO We may want this to be an instance method so that it can be overriden.
      return CURRENCY_FORMAT. format (((CurrencyDouble) obj). val);
   }
    
    
   /*-------------------------- End Methods ---------------------------*/

   /* End of CurrencyDoubleUI */
}

