/* 
   (C) Copyright 2004 eKnowlogie Inc., All rights reserved.
   eKnowlogie Proprietary / Confidential.  Use is subject to license terms.
*/

package com.eknowlogie.business.aliorsum;

import com.eknowlogie.aliorsum.*;
import com.eknowlogie.business.model.Phone;
import com.eknowlogie.util.Strings;

/** <p>ElementaryUI for recipients of type Phone.  The methods in this class update a recipient 
    object without replacing the object.</p> 
    
    @author Romel Rivera, eKnowlogie. Inc.
*/

public class PhoneUI extends ElementaryUI {
	
	public static final String INVALID_PHONE_FORMAT = "Phone number must contain 10 digits.";

   /*------------------------- Begin Methods --------------------------*/
	
   public boolean validate (String inputValue) {
   	  Long newNumber = (Long) parse (inputValue);
   	  if (newNumber != null) {
   	     Phone phone = (Phone) getValue ();
         phone. number = newNumber. longValue ();
      }
   	  return newNumber != null;
   }

   /** {@inheritDoc}
     
       <p>Parses a phone number into a Long object.</p> 
   */
	
   public Object parse (String inputValue) {
      if (inputValue == null || inputValue. length () == 0) {
         addValidation (INVALID_PHONE_FORMAT);
         return null;
      }
      inputValue = Strings. removeNonNumeric (inputValue);
      if (inputValue. length () != 10) {
         addValidation (INVALID_PHONE_FORMAT);
         return null;
      }
      try { return new Long (inputValue); }
      catch (NumberFormatException e) {
     	 addValidation (INVALID_PHONE_FORMAT);
     	 return null;
      }
   }

   public String format () {
      if (invalidInputValue != null) 
         return invalidInputValue;
      else {
         Phone phone = (Phone) getValue ();
         if (phone == null || phone. number == 0)
            return "";
         String text = new Long (phone. number). toString ();
         String formattedText = "(" + text. substring (0,3) + ")" + text. substring (3,6) + "-" 
	                            + text. substring (6,10);
         return formattedText;
      }
   }

   /*-------------------------- End Methods ---------------------------*/

   /* End of PhoneUI */
}

